@@ -3,11 +3,6 @@ package srunModels
 import "github.com/Mmx233/BitSrunLoginGo/v1/transfer"
 
 type LoginInfo struct {
-	UrlLoginPage       string
-	UrlGetChallengeApi string
-	UrlLoginApi        string
-	UrlCheckApi        string
-
 	Ip              string
 	Token           string
 	EncryptedInfo   string
