@@ -1,8 +1,11 @@
 package srunTransfer
 
+import "net/http"
+
 type LoginForm struct {
 	Domain   string `json:"domain"`
 	UserName string `json:"username"`
+	//运营商类型
 	UserType string `json:"user_type"`
 	PassWord string `json:"password"`
 }
@@ -20,14 +23,9 @@ type LoginInfo struct {
 }
 
 type Login struct {
-	//文件日志输出开关
-	Demo bool
-	//控制台日志打印开关
-	OutPut bool
-	//登陆前是否检查网络，只在离线时登录
-	CheckNet bool
-	//网络检查超时时间
-	Timeout uint
+	//调用 API 时直接访问 https URL
+	Https bool
 	//登录参数，不可缺省
 	LoginInfo LoginInfo
+	Client    *http.Client
 }
